pub struct SyncConfig {
pub provider: String,
pub value: String,
}Expand description
Cached sync data for a secret (provider + encrypted value)
Fields
provider: Stringvalue: StringTrait Implementations
Sourceimpl Clone for SyncConfig
impl Clone for SyncConfig
Sourcefn clone(&self) -> SyncConfig
fn clone(&self) -> SyncConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SyncConfig
impl Debug for SyncConfig
Sourceimpl<'de> Deserialize<'de> for SyncConfig
impl<'de> Deserialize<'de> for SyncConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SyncConfig
impl JsonSchema for SyncConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SyncConfig
impl RefUnwindSafe for SyncConfig
impl Send for SyncConfig
impl Sync for SyncConfig
impl Unpin for SyncConfig
impl UnsafeUnpin for SyncConfig
impl UnwindSafe for SyncConfig